@@ -13,13 +13,13 @@ getSrcRegion <- function(srcfile, x1, x2, y1, y2) {
   lines <- getSrcLines(srcfile, x1, x2)
   
   text <- if (length(lines) == 1) {
-    substr(lines[1], y1, y2 - 1)
+    str_sub(lines[1], y1, y2 - 1)
   } else {
     c(
-      substr(lines[1], y1, 1e6),
+      str_sub(lines[1], y1, 1e6),
       lines[-c(1, length(lines))],
-      substr(lines[length(lines)], 0, y2 - 1)
+      str_sub(lines[length(lines)], 0, y2 - 1)
     )
   }
-  paste(text, collapse="\n")
+  str_c(text, collapse="\n")
 }
